|PyPI| |Python|

Description
===========
An easy plotting GUI for Python.


.. |PyPI| image:: https://img.shields.io/pypi/v/GuiPy.svg?logo=pypi&logoColor=white&label=PyPI
   :target: https://pypi.python.org/pypi/GuiPy
   :alt: PyPI - Latest Release
.. |Python| image:: https://img.shields.io/badge/Python-3.6%2B-blue?logo=python&logoColor=white
   :target: https://pypi.python.org/pypi/GuiPy
   :alt: PyPI - Python Versions
